/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005 Hugo Ruscitti : hugoruscitti@yahoo.com.ar
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "juego.h"


/*
 * retorna: 1 en caso de error
 */
int juego_iniciar (struct Juego * juego, SDL_Surface * screen)
{
	juego->fondo = SDL_LoadBMP ("ima/fondo.bmp");
	
	if (juego->fondo == NULL)
	{
		printf ("No se puede crear el fondo.\n");
		return 1;
	}

	SDL_BlitSurface (juego->fondo, NULL, screen, NULL);
	
	juego->pelota = (struct Pelota *) malloc (sizeof (struct Pelota));

	if (juego->pelota == NULL)
	{
		printf ("No se puede crear la pelota del juego.\n");
		return 1;
	}

	if (pelota_iniciar (juego->pelota))
		return 1;
	
	SDL_Flip (screen);
	return 0;
}


void juego_ciclo_logico (struct Juego * juego)
{	
	pelota_actualizar (juego->pelota);
}


void juego_ciclo_grafico (struct Juego * juego, SDL_Surface * screen)
{
	static SDL_Rect dirty = {0, 0, 0, 0};

	SDL_BlitSurface (juego->fondo, &dirty, screen, &dirty);
	SDL_UpdateRect (screen, dirty.x, dirty.y, dirty.w, dirty.h);

	pelota_imprimir (juego->pelota, screen, & dirty);
	SDL_UpdateRect (screen, dirty.x, dirty.y, dirty.w, dirty.h);
}


void juego_terminar (struct Juego * juego)
{
	free (juego->pelota);
	SDL_FreeSurface (juego->fondo);
}
