/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005 Hugo Ruscitti : hugoruscitti@yahoo.com.ar
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _PERSONAJE_H
#define _PERSONAJE_H

#include "util.h"
#include "dirty.h"

#define EJE_X 43
#define EJE_Y 107

enum estados { PARADO, DERECHA, IZQUIERDA, SALTANDO, _ESTADOS };

typedef struct Personaje
{
	SDL_Surface * imagen;
	SDLKey tecla_derecha;
	SDLKey tecla_izquierda;
	SDLKey tecla_saltar;
	enum estados estado;
	int x;
	int y;
	int limite_izquierdo;
	int limite_derecho;
	int paso;
	int cuadro;
	int delay;
	int velocidad_inicial;
} Personaje;


int personaje_crear (Personaje ** personaje, int numero_jugador);
void personaje_terminar (Personaje * personaje);
void personaje_actualizar (Personaje * personaje, Uint8 * teclas);
void personaje_imprimir (Personaje * personaje, Dirty * dirty, SDL_Surface * screen);
void personaje_parado (Personaje * personaje, Uint8 * teclas);
void personaje_izquierda (Personaje * personaje, Uint8 * teclas);
void personaje_derecha (Personaje * personaje, Uint8 * teclas);
void personaje_avanzar_animacion (Personaje * personaje);
void personaje_cambiar_estado (Personaje * personaje, enum estados nuevo);
void personaje_saltando (Personaje * personaje, Uint8 * teclas);
void personaje_mover (Personaje * personaje, int incremento_x);

#endif
